#' landscapetools
#'
#' \emph{landscapetools} provides utility functions to work with landscape data
#' (raster* Objects).
#'
#' @useDynLib landscapetools, .registration = TRUE
#' @importFrom Rcpp sourceCpp
"_PACKAGE"

globalVariables(c("value", ".", "id", "y", "z"))
